==> rosegarden-trinity_3.5.13.2.orig.tar.xz: rosegarden-trinity-3.5.13.2/src/gui/configuration/LatencyConfigurationPage.h <==

/* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */

/*
    Rosegarden
    A MIDI and audio sequencer and musical notation editor.

    This program is Copyright 2000-2008
        Guillaume Laurent   <glaurent@telegraph-road.org>,
        Chris Cannam        <cannam@all-day-breakfast.com>,
        Richard Bown        <richard.bown@ferventsoftware.com>

    The moral rights of Guillaume Laurent, Chris Cannam, and Richard
    Bown to claim authorship of this work have been asserted.

    Other copyrights also apply to some parts of this work.  Please
    see the AUTHORS file and individual file headers for details.

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.  See the file
    COPYING included with this distribution for more information.
*/

#ifndef _RG_LATENCYCONFIGURATIONPAGE_H_
#define _RG_LATENCYCONFIGURATIONPAGE_H_

#include "TabbedConfigurationPage.h"
#include <tqstring.h>
#include <klocale.h>
#include <tqslider.h>


class TQWidget;
class TQPushButton;
class KConfig;


namespace Rosegarden
{

class RosegardenGUIDoc;


/**
 * Latency Configuration page
 *
 * (application-wide settings)
 */
class LatencyConfigurationPage : public TabbedConfigurationPage
{
    Q_OBJECT
  TQ_OBJECT

public:
    LatencyConfigurationPage(RosegardenGUIDoc *doc,
                             KConfig *cfg,
                             TQWidget *parent=0, const char *name=0);

    virtual void apply();

    static TQString iconLabel() { return i18n("Latency"); }
    static TQString title()     { return i18n("Sequencer Latency"); }

    int getJACKPlaybackValue() { return m_jackPlayback->value(); }
    int getJACKRecordValue() { return m_jackRecord->value(); }

protected slots:
    // Get the latest latency values from the sequencer
    //
    void slotFetchLatencyValues();

protected:

    //--------------- Data members ---------------------------------

    TQSlider* m_jackPlayback;
    TQSlider* m_jackRecord;

    TQPushButton* m_fetchLatencyValues;
};



}

#endif

==> rosegarden-trinity-14.0.7.tar.xz: rosegarden-trinity-14.0.7/src/gui/configuration/LatencyConfigurationPage.h <==

/* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */

/*
    Rosegarden
    A MIDI and audio sequencer and musical notation editor.

    This program is Copyright 2000-2008
        Guillaume Laurent   <glaurent@telegraph-road.org>,
        Chris Cannam        <cannam@all-day-breakfast.com>,
        Richard Bown        <richard.bown@ferventsoftware.com>

    The moral rights of Guillaume Laurent, Chris Cannam, and Richard
    Bown to claim authorship of this work have been asserted.

    Other copyrights also apply to some parts of this work.  Please
    see the AUTHORS file and individual file headers for details.

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.  See the file
    COPYING included with this distribution for more information.
*/

#ifndef _RG_LATENCYCONFIGURATIONPAGE_H_
#define _RG_LATENCYCONFIGURATIONPAGE_H_

#include "TabbedConfigurationPage.h"
#include <tqstring.h>
#include <tdelocale.h>
#include <tqslider.h>


class TQWidget;
class TQPushButton;
class TDEConfig;


namespace Rosegarden
{

class RosegardenGUIDoc;


/**
 * Latency Configuration page
 *
 * (application-wide settings)
 */
class LatencyConfigurationPage : public TabbedConfigurationPage
{
    Q_OBJECT
  

public:
    LatencyConfigurationPage(RosegardenGUIDoc *doc,
                             TDEConfig *cfg,
                             TQWidget *parent=0, const char *name=0);

    virtual void apply();

    static TQString iconLabel() { return i18n("Latency"); }
    static TQString title()     { return i18n("Sequencer Latency"); }

    int getJACKPlaybackValue() { return m_jackPlayback->value(); }
    int getJACKRecordValue() { return m_jackRecord->value(); }

protected slots:
    // Get the latest latency values from the sequencer
    //
    void slotFetchLatencyValues();

protected:

    //--------------- Data members ---------------------------------

    TQSlider* m_jackPlayback;
    TQSlider* m_jackRecord;

    TQPushButton* m_fetchLatencyValues;
};



}

#endif
